@@ -134,8 +134,12 @@ def main():
         class Restart(Exception):
             pass
     
-    opts, args = getopt.getopt(sys.argv[1:], 'hc:', ['help', 'command='])
+    opts, args = getopt.getopt(sys.argv[1:], 'hc:', ['--help', '--command='])
 
+    if not args:
+        print(_usage)
+        sys.exit(2)
+    
     commands = []
     for opt, optarg in opts:
         if opt in ['-h', '--help']:
@@ -144,10 +148,6 @@ def main():
         elif opt in ['-c', '--command']:
             commands.append(optarg)
 
-    if not args:
-        print(_usage)
-        sys.exit(2)
-    
     mainpyfile = args[0]     # Get script filename
     if not os.path.exists(mainpyfile):
         print('Error:', mainpyfile, 'does not exist')
